@@ -43,19 +43,25 @@ class StateMachine(CloudFormationLintRule):
         state_key_types = {
             "Pass": ["Result", "ResultPath", "Parameters"],
             "Task": [
+                "Credentials",
                 "Resource",
+                "Parameters",
                 "ResultPath",
                 "ResultSelector",
                 "Retry",
                 "Catch",
                 "TimeoutSeconds",
+                "TimeoutSecondsPath",
                 "Parameters",
                 "HeartbeatSeconds",
+                "HeartbeatSecondsPath",
             ],
             "Map": [
                 "MaxConcurrency",
                 "Iterator",
                 "ItemsPath",
+                "ItemProcessor",
+                "ItemSelector",
                 "ResultPath",
                 "ResultSelector",
                 "Retry",
